@@ -10,10 +10,12 @@ PyPI: https://pypi.org/project/pyspecan/
 This is intended to be used as a callable module (or a script), but can be used as a library
 """
 
-__version__ = "0.2.0"
+__version__ = "0.3.0"
 __author__ = "Anonoei <to+dev@an0.cx>"
 
-from .config import config, Mode
+from . import _internal
+
+from .config import config, Mode, View
 from . import err
 from . import obj
 from . import utils
